* ------------------------------------------------------------------------------
* Blauer Band: Bundestagswahl 2013
* Schoen/Rudnik: Wirkungen von Einstellungen zur europäischer Schulden- und 
* Währungskrise auf das Wahlverhalten bei der Bundestagswahl 2013
* ------------------------------------------------------------------------------


* Datengrundlage:  GLES Vorwahl- und Nachwahl-Querschnitt 2013, ZA5702 - Version 2
clear
clear matrix
set maxvar 30000
cd "L:\Agatha\Blauer Band BTW13"
use "ZA5702_v2-0-0.dta", clear



* Definition der fehlenden Werte
foreach var of varlist _all {
	capture confirm numeric var `var'
	if !_rc {
		mvdecode `var', mv(-71=.p \-72=.o \-81=.n \-82=.m \-83=.l ///
				 \-84=.k \-85=.j \-86=.i \-92=.h \-93=.g ///
				 \-94=.f \-95=.e \-96=.d \-97=.c \-98=.b ///
				 \-99=.a)
		local lab: value label `var'
		if "`lab'"!="" {
			label define `lab' ///
			.a"keine Angabe" ///
			.b"weiss nicht" ///
			.c"trifft nicht zu" ///
			.d"Split" ///
			.e"nicht teilgenommen" ///
			.f"nicht in Auswahlgesamtheit" ///
			.g"Interview abgebrochen" ///
			.h"Fehler in Daten" ///
			.i"nicht wahlberechtigt" ///
			.j"nicht waehlen" ///
			.k"keine Erst-/Zweitstimme abgegeben" ///
			.l"ungueltig waehlen" ///
			.m"keine andere Partei waehlen" ///
			.n"noch nicht entschieden" ///
			.o"nicht einzuschaetzen" ///
			.p"nicht bekannt", modify
			}
		}
}

*

* Wahlabsicht (Zweitstimme)
recode v11ba (4=2) (5=3) (6=4) (7=5) (322=6) (206 215 801=.), gen (voteint)
replace voteint=7 if v10==4 | v10==5
label define lvotei 1 "Union" 2 "SPD" 3 "FDP" 4 "Gruene" 5 "Linke" 6 "AfD" ///
		7 "Nichtwahl"
label values voteint lvotei 
label variable voteint "Wahlabsicht (Zweitstimme)"

* Dummies 
gen vi_union=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_union=1 if voteint==1
gen vi_spd=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_spd=1 if voteint==2
gen vi_fdp=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_fdp=1 if voteint==3
gen vi_gruen=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_gruen=1 if voteint==4
gen vi_linke=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_linke=1 if voteint==5
gen vi_afd=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_afd=1 if voteint==6
gen vi_nov=0 if voteint>=1 & voteint<7.1 & survey==1
replace vi_nov=1 if voteint==7


* Wahlentscheidung BTW 2013 (Zweitstimme)
recode n11ba (1=1) (4=2) (5=3) (6=4) (7=5) (322=6) (206 215 801=.), gen (btw13)
replace btw13=7 if n10==2
label define lbtw13 1 "Union" 2 "SPD" 3 "FDP" 4 "Gruene" 5 "Linke" 6 "AfD" ///
		7 "Nichtwahl"
label values btw13 lbtw13
label variable btw13 "Wahlentscheidung BTW 2013 (Zweitstimme)"

* Dummies
gen vc_union=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_union=1 if btw13==1
gen vc_spd=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_spd=1 if btw13==2
gen vc_fdp=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_fdp=1 if btw13==3
gen vc_gruen=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_gruen=1 if btw13==4
gen vc_linke=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_linke=1 if btw13==5
gen vc_afd=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_afd=1 if btw13==6
gen vc_nov=0 if btw13>=1 & btw13<7.1 & survey==2
replace vc_nov=1 if btw13==7


* Zufriedenheit mit der Regierungsperformanz in der Schuldenkrise
recode v38 (1=5) (2=4) (3=3) (4=2) (5=1), gen(perfgov)
recode n38 (1=5) (2=4) (3=3) (4=2) (5=1), gen(nperfgov)
replace perfgov=nperfgov if survey==2
replace perfgov=(perfgov-1)/4
label define lperfg 0 "sehr unzufrieden" 1 "sehr zufrieden"
label values perfgov lperfg
label variable perfgov "Regierungsperformanz"
drop nperfgov


* Einstellung zu einer finanziellen Unterstützung verschuldeter EU-Staaten
recode vn40e (1=5) (2=4) (3=3) (4=2) (5=1), gen(prefego)
mvdecode prefego, mv(-99=.a \ -98=.b)
replace prefego=(prefego-1)/4
label define lprefego 0 "stimme überhaupt nicht zu" 1 "stimme voll und ganz zu"
label values prefego lprefego
label variable prefego "Finanz. Unterstützung"


* Parteiidentifikation
recode vn119a (1 2 3=1) (4=2) (5=3) (6=4) (7=5) (322=6) (206 215 801=.) (808 809=7), ///
	gen(pid)
mvdecode pid, mv(-99=.a \ -98=.b)
label define lpid 1 "Union" 2 "SPD" 3 "FDP" 4 "Gruene" 5 "Linke" 6 "AfD" ///
		7 "keine PID"
label values pid lpid
label variable pid "Parteiidentifikation"


* pid dummies
gen union_d=0
replace union_d=1 if vn119a==1 | vn119a==2 | vn119a==3
gen spd_d=0
replace spd_d=1 if vn119a==4
gen fdp_d=0
replace fdp_d=1 if vn119a==5
gen gruen_d=0
replace gruen_d=1 if vn119a==6
gen linke_d=0
replace linke_d=1 if vn119a==7
gen afd_d=0
replace afd_d=1 if vn119a==322
gen nopid_d=0
replace nopid_d=1 if vn119a==808 | vn119a==809

gen pidstr=0 if vn120~=-97
replace pidstr=(5-vn120)/4 if vn120>0
fre pidstr
gen union_s=union_d*pidstr
gen spd_s=spd_d*pidstr
gen fdp_s=fdp_d*pidstr
gen gruen_s=gruen_d*pidstr
gen linke_s=linke_d*pidstr
gen afd_s=afd_d*pidstr
fre union_s-afd_s


* Links-rechts-Position
gen lrscale=vn62
mvdecode lrscale, mv(-99=.a \ -98=.b \ -97=.c)
replace lrscale=(lrscale-1)/10
label variable lrscale "Links-rechts-Position"


* Regierung sollte Einkommensunterschiede verringern
recode vn40d (1=5) (2=4) (3=3) (4=2) (5=1), gen(redist1)
mvdecode redist1, mv(-99=.a \ -98=.b)
replace redist1=(redist1-1)/4
label define lredist1 0 "stimme überhaupt nicht zu" 1 "stimme voll und ganz zu"
label values redist1 lredist1
label variable redist1 "Einkommensgleichheit"


* Steuern vs. Sozialtransfers
gen redist2=vn67
mvdecode redist2, mv(-99=.a \ -98=.b)
replace redist2=(redist2-1)/10
label define redist2 0 "weniger Steuern und Abgaben" 1 "mehr sozialstaatliche Leistungen"
label variable redist2 "Umverteilung"


* Ethnozentrismus 
recode vn40a (1=5) (2=4) (3=3) (4=2) (5=1), gen(immig1)
mvdecode immig1, mv(-99=.a \ -98=.b)
replace immig1=(immig1-1)/4
label define limmigt1 0 "stimme überhaupt nicht zu" 1 "stimme voll und ganz zu"
label values immig1 limmig1
label variable immig1 "Einwanderer sollten sich der deutschen Kultur anpassen"

gen immig2=vn68
mvdecode immig2, mv(-99=.a \ -98=.b)
replace immig2=(immig2-1)/10
label define limmig2 0 "Zuzug Auslaender erleichtern" 1 "Zuzug Auslaender einschraenken"
label values immig2 limmig2
label variable immig2 "immigration"

fre immig1 immig2
gen immig3=(immig1+immig2)/2
fre immig3
label variable immig3 "Ethnozentrismus"


* Sicherung der Energieversorgung auch durch Atomkraft
fre vn40g
gen nuk=(5-vn40g)/4 if vn40g>0
fre nuk
label variable nuk "Kernenergie"


* Kandidatenbewertung
fre vn22a
gen merkel=(vn22a-1)/10 if vn22a>0
lab var merkel "Merkel"
gen steinb=(vn22b-1)/10 if vn22b>0
lab var steinb "Steinbrück"
gen brüder=(vn22c-1)/10 if vn22c>0
lab var brüder "Brüderle"
gen gysi=(vn22d-1)/10 if vn22d>0
lab var gysi "Gysi"
gen tritt=(vn22e-1)/10 if vn22e>0
lab var tritt "Trittin"


* Angst vor der Schuldenkrise
fre vn35
recode vn35 (1=5) (2=4) (3=3) (4=2) (5=1), gen(fear)
mvdecode fear, mv(-99=.a \ -98=.b)
replace fear=(fear-1)/4
label define lfear 0 "ueberhaupt keine Angst" 1 "sehr grosse Angst"
label values fear lfear
label variable fear "Angst"
fre fear


* Politisches Interesse
recode vn3 (1=5) (2=4) (3=3) (4=2) (5=1), gen(interest)
mvdecode interest, mv(-99=.a \ -98=.b)
replace interest=(interest-1)/4
label define linterest 0 "überhaupt nicht" 1 "stark"
label values interest linterest
label variable interest "Politisches Interesse"


* Alter
gen age = (2013 - vn2c) if vn2c<1996
replace age=(age-18)/81
lab var age "Alter"


* Geschlecht
tab1 vn1
recode vn1 (2 = 1) (1 = 0), gen(female)
lab var female "Frau"


* Bildung
gen eduhi = 0
replace eduhi = 1 if vn163 == 4 | vn163 == 5
lab var eduhi "Bildung hoch"
gen edulo= 0
replace edulo = 1 if vn163 == 1 | vn163 == 2
lab var edulo "Bildung niedrig"


* Region
recode intreg (1 = 1) (2 = 0), gen(ost)
lab var ost "Ostdeutschland"



* Kenntnis von der AfD
* Vorwahl
gen afd_know=1 if v16d==1 | v16d==2 | v16d==3 | v16d==4 | v16d==5
replace afd_know=0 if v16d==.p
replace afd_know=. if survey==2
label define afd_know 1 "kenne die AfD" 0 "kenne die AfD nicht"
label values afd_know afd_know
label var afd_know "Kenntnis von der AfD"
fre afd_know
mean afd_know, over (voteint)
tab afd_know voteint, col row

* Nachwahl
fre vn21h
gen afd_know1=1
replace afd_know1=0 if vn21h==.p
replace afd_know1=. if survey==1
replace afd_know1=. if vn21h==.b | vn21h==.a
label var afd_know1 "Kenntnis von der AfD"



*** Deskriptive Statistik
sum voteint age female edulo eduhi ost inter fear afd_know lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego perfgov if vn2c<1996 & survey==1
sum btw13 age female edulo eduhi ost inter fear afd_know1 lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego perfgov if vn2c<1996 & survey==2

*** Zusammenhang zwischen Regierungsperformanz und Einstellung zur finanz. Unterstützung
pwcorr prefego perfgov if vn2c<1996 & survey==1
pwcorr prefego perfgov if vn2c<1996 & survey==2




* ------------------------------------------------------------------------------
* Heckman-Probit-Regressionen
* ------------------------------------------------------------------------------

*** Grundmodell

* Vorwahl
heckprobit vi_union age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_spd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_fdp age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_gruen age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_linke age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_afd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_nov age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(*) expression(normal(xb(afd_know)))
margins [pweight=vn_w_ipfges_1], dydx(*) expression(normal(xb(vi_union)))




* Nachwahl
heckprobit vc_union age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_spd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_fdp age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_gruen age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_linke age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_afd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_nov age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(*) expression(normal(xb(afd_know1)))
margins [pweight=vn_w_ipfges_1], dydx(*) expression(normal(xb(vc_union)))





*** Einfluss der Bewertung der Regierungsperformanz auf das Wahlverhalten in Abhängigkeit von der Haltung zur finanziellen Unterstützung

* Vorwahl *
heckprobit vi_union age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_spd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_fdp age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_gruen age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_linke age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_afd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_nov age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)


margins [pweight=vn_w_ipfges_1], dydx(perfgov) at(prefego=(0(.25)1)) expression(normal(xb(vi_union)))



* Nachwahl *
heckprobit vc_union age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_spd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_fdp age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_gruen age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_linke age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_afd age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_nov age edulo eduhi ost interest lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel c.perfgov##c.prefego [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(perfgov) at(prefego=(0(.25)1)) expression(normal(xb(vc_union)))





*** Einfluss der Haltung zur finanziellen Unterstützung und Einfluss der Regierungsperformanz auf das Wahlverhalten in Abhängigkeit vom politischen Interesse

* Vorwahl *
* finanz. Unterstützung *
heckprobit vi_union age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_spd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_fdp age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_linke age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_afd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_nov age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vi_union)))


* Regierungsperformanz *
heckprobit vi_union age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_spd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_fdp age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_linke age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_afd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vi_nov age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(perfgov) at(interest=(0(.25)1)) expression(normal(xb(vi_union)))



* Nachwahl *
* finanz. Unterstützung *
heckprobit vc_union age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_spd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_fdp age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_linke age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_afd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_nov age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vc_union)))


* RegierungsRegierungsperformanz *
heckprobit vc_union age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_spd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_fdp age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_linke age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_afd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
heckprobit vc_nov age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)

margins [pweight=vn_w_ipfges_1], dydx(perfgov) at(interest=(0(.25)1)) expression(normal(xb(vc_union)))



	
	
* ------------------------------------------------------------------------------
* Grafiken: Durchschnittliche marginale Effekte (DME) der Haltung zur finanziellen 
* Unterstützung und der Leistung der Regierung in Abhängigkeit vom politischen 
* Interesse für die Wahl ausgewählter Parteien
* ------------------------------------------------------------------------------

* Vorwahl

*** Grüne ***
heckprobit vi_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vi_gruen))) saving(file1, replace)
heckprobit vc_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vc_gruen))) saving(file2, replace)
combomarginsplot file1 file2, ///
    labels("Grüne (Vorwahl)" "Grüne (Nachwahl)") noci scheme(s2mono) legend(cols(2)) xtitle("Politisches Interesse") ytitle("DME Haltung zur finanziellen Unterstützung") title("") graphregion(color(white)) bgcolor(white) ylabel(-0.4(0.2)0.4, gmin gmax angle(horizontal))

*** AfD ***
heckprobit vi_afd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vi_afd))) saving(file3, replace)
heckprobit vc_afd age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vc_afd))) saving(file4, replace)
combomarginsplot file3 file4, ///
    labels("AfD (Vorwahl)" "AfD (Nachwahl)") noci scheme(s2mono) legend(cols(2)) xtitle("Politisches Interesse") ytitle("DME Haltung zur finanziellen Unterstützung") title("") graphregion(color(white)) bgcolor(white) ylabel(-0.4(0.2)0.4, gmin gmax angle(horizontal))

	
	
* Nachwahl
	
*** Grüne ***
heckprobit vc_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest  [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vc_gruen))) saving(file7, replace)
heckprobit vi_gruen age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(perfgov) at(interest=(0(.25)1)) expression(normal(xb(vi_gruen))) saving(file8, replace)
combomarginsplot file7 file8, ///
    labels("Grüne (Vorwahl)" "Grüne (Nachwahl)") noci scheme(s2mono) legend(cols(2)) xtitle("Politisches Interesse") ytitle("DME Leistung der Regierung") title("") graphregion(color(white)) bgcolor(white) ylabel(-0.4(0.2)0.4, gmin gmax angle(horizontal))

*** Union ***
heckprobit vc_union age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel perfgov c.prefego##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know1 = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(prefego) at(interest=(0(.25)1)) expression(normal(xb(vc_union))) saving(file5, replace)
heckprobit vi_union age edulo eduhi ost lrscale immig3 redist2 redist1 nuk union_d spd_d steinb merkel prefego c.perfgov##c.interest [pweight = vn_w_ipfges_1] if vn2c<1996, select(afd_know = edulo eduhi female interest redist1 immig3 prefego fear)
margins [pweight=vn_w_ipfges_1], dydx(perfgov) at(interest=(0(.25)1)) expression(normal(xb(vi_union))) saving(file6, replace)
combomarginsplot file5 file6, ///
    labels("Union (Vorwahl)" "Union (Nachwahl)") noci scheme(s2mono) legend(cols(2)) xtitle("Politisches Interesse") ytitle("DME Leistung der Regierung") title("") graphregion(color(white)) bgcolor(white) ylabel(-0.4(0.2)0.4, gmin gmax angle(horizontal))


	
	
	
	

